Package 'zuericolors'

Title: Statistik Stadt Zuerich Colors (zuericolors)
Description: zuericolors contains all colors needed by Statistik Stadt Zürich (SSZ).
Authors: Alessandro Feller [aut, cre], Statistik Stadt Zürich [cph, fnd]
Maintainer: Alessandro Feller <[email protected]>
License: MIT + file LICENSE
Version: 1.0.0
Built: 2026-06-03 07:24:40 UTC
Source: https://github.com/StatistikStadtZuerich/zuericolors

Help Index


Get Zuericolors Palettes

Description

Function to access color values of a specific zuericolors palette. To see the available palettes, call view_zuericolors().

Usage

get_zuericolors(palette = names(palettes), nth)

Arguments

palette

Name of a specific palette; to see the available palettes, call view_zuericolors()

nth

Position of a specific color in a palette, optional

Value

the color(s) as hex strings

Examples

# Get colors of palette 'qual12'
get_zuericolors("qual12")

# Get third color value of palette 'qual12'
get_zuericolors("qual12", 3)

# Get first three color values of palette 'qual12'
get_zuericolors("qual12", 1:3)

View Zuericolors Palettes

Description

Function to visually inspect values and colors of a specific zuericolors palette

Usage

view_zuericolors(palette)

Arguments

palette

Name of a specific palette. if it is not provided, all palettes are plotted.

Value

returns a plot of the requested color/palette

Examples

view_zuericolors("qual12")