| Title: | Statistik Stadt Zuerich Colors (zuericolors) |
|---|---|
| Description: | zuericolors contains all colors needed by Statistik Stadt Zürich (SSZ). |
| Authors: | Alessandro Feller [aut, cre], Statistik Stadt Zürich [cph, fnd] |
| Maintainer: | Alessandro Feller <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 1.0.0 |
| Built: | 2026-06-03 07:24:40 UTC |
| Source: | https://github.com/StatistikStadtZuerich/zuericolors |
Function to access color values of a specific zuericolors palette. To see the available palettes, call view_zuericolors().
get_zuericolors(palette = names(palettes), nth)get_zuericolors(palette = names(palettes), nth)
palette |
Name of a specific palette; to see the available palettes, call |
nth |
Position of a specific color in a palette, optional |
the color(s) as hex strings
# Get colors of palette 'qual12' get_zuericolors("qual12") # Get third color value of palette 'qual12' get_zuericolors("qual12", 3) # Get first three color values of palette 'qual12' get_zuericolors("qual12", 1:3)# Get colors of palette 'qual12' get_zuericolors("qual12") # Get third color value of palette 'qual12' get_zuericolors("qual12", 3) # Get first three color values of palette 'qual12' get_zuericolors("qual12", 1:3)
Function to visually inspect values and colors of a specific zuericolors palette
view_zuericolors(palette)view_zuericolors(palette)
palette |
Name of a specific palette. if it is not provided, all palettes are plotted. |
returns a plot of the requested color/palette
view_zuericolors("qual12")view_zuericolors("qual12")